@@ -1,7 +1,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2010  Otfried Cheong
+    Copyright (C) 1993-2011  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -72,9 +72,15 @@ extern "C" {
 #include "lua.h"
 #include "lauxlib.h"
 #include "lualib.h"
-#include "lfs.h"
 }
 
+#ifdef NO_CHDIR
+#define chdir(p)	(-1)
+#define chdir_error	"Function 'chdir' not provided by system"
+#else
+#define chdir_error	strerror(errno)
+#endif
+
 /* Define 'strerror' for systems that do not implement it */
 #ifdef NO_STRERROR
 #define strerror(_)	"System unable to describe the error"
@@ -704,7 +710,7 @@ static const struct luaL_reg fslib[] = {
 	{NULL, NULL},
 };
 
-extern "C" int luaopen_lfs (lua_State *L) {
+extern int luaopen_lfs (lua_State *L) {
 	dir_create_meta (L);
 	luaL_register (L, "lfs", fslib);
 	set_info (L);
