@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2010  Otfried Cheong
+    Copyright (C) 1993-2011  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -518,7 +518,7 @@ bool Document::exportView(const char *fname, TFormat format, uint flags,
   } else {
     // Postscript
     PsWriter writer(stream, this, (flags & ENoColor));
-    if (!writer.createHeader()) {
+    if (!writer.createHeader(pno, vno)) {
       std::fclose(fd);
       return false;
     }
