@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2010  Otfried Cheong
+    Copyright (C) 1993-2011  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -202,7 +202,9 @@ String Platform::latexDirectory()
 #ifdef __MINGW32__
   String latexDir;
   const char *p = getenv("IPELATEXDIR");
-  if (p) {
+  if (getenv("IPEWINE"))
+    latexDir = "z:\\tmp\\ipelatex";
+  else if (p) {
     latexDir = p;
   } else {
     TCHAR szPath[MAX_PATH];
@@ -286,26 +288,36 @@ String Platform::readFile(String fname)
 int Platform::runPdfLatex(String dir)
 {
 #ifdef WIN32
-  String s = dir + "runlatex.bat";
-  std::FILE *f = std::fopen(s.z(), "wb");
-  if (!f)
-    return -1;
+  const char *wine = getenv("IPEWINE");
+  if (wine) {
+    int secs = Lex(wine).getInt();
+    std::system("/bin/sh -c \"cd /tmp/ipelatex; rm -f ipetemp.log;"
+		"pdflatex ipetemp.tex\"");
+    fprintf(stderr, "Waiting %d seconds for pdflatex\n", secs);
+    Sleep(secs * 1000);
+    return 0;
+  } else {
+    String s = dir + "runlatex.bat";
+    std::FILE *f = std::fopen(s.z(), "wb");
+    if (!f)
+      return -1;
 
-  if (dir.size() > 2 && dir[1] == ':')
-    fprintf(f, "%s\r\n", dir.substr(0, 2).z());
+    if (dir.size() > 2 && dir[1] == ':')
+      fprintf(f, "%s\r\n", dir.substr(0, 2).z());
 
-  // CMD.EXE input needs to be encoded in "OEM codepage",
-  // which can be different from "Windows codepage"
-  Buffer oemDir(2 * dir.size() + 1);
-  CharToOemA(dir.z(), oemDir.data());
+    // CMD.EXE input needs to be encoded in "OEM codepage",
+    // which can be different from "Windows codepage"
+    Buffer oemDir(2 * dir.size() + 1);
+    CharToOemA(dir.z(), oemDir.data());
 
-  fprintf(f, "cd \"%s\"\r\n", oemDir.data());
-  fprintf(f, "pdflatex ipetemp.tex\r\n");
-  std::fclose(f);
+    fprintf(f, "cd \"%s\"\r\n", oemDir.data());
+    fprintf(f, "pdflatex ipetemp.tex\r\n");
+    std::fclose(f);
 
-  s = String("call \"") + dir + String("runlatex.bat\"");
-  std::system(s.z());
-  return 0;
+    s = String("call \"") + dir + String("runlatex.bat\"");
+    std::system(s.z());
+    return 0;
+  }
 #else
   String s("cd ");
   s += dir;
