@@ -4,7 +4,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2010  Otfried Cheong
+    Copyright (C) 1993-2011  Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -32,7 +32,6 @@
 #include "ipedoc.h"
 
 #include <cerrno>
-#include <QString>
 
 using namespace ipe;
 using namespace ipelua;
@@ -43,7 +42,7 @@ static const char * const format_name[] =
   { "xml", "pdf", "eps", "ipe5", "unknown" };
 
 void ipelua::make_metatable(lua_State *L, const char *name,
-		    const struct luaL_Reg *methods)
+			    const struct luaL_Reg *methods)
 {
   luaL_newmetatable(L, name);
   lua_pushstring(L, "__index");
@@ -67,8 +66,8 @@ bool ipelua::is_type(lua_State *L, int ud, const char *tname)
 
 String ipelua::check_filename(lua_State *L, int index)
 {
-  QString s = QString::fromUtf8(luaL_checkstring(L, index));
-  return String(s.toLocal8Bit().constData());
+  // TODO: local encoding!
+  return String(luaL_checkstring(L, index));
 }
 
 // --------------------------------------------------------------------
